==> haskell-uri-bytestring-0.2.3.3-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-bytestring
version: 0.2.3.3
id: uri-bytestring-0.2.3.3-5AAepp46BcPG5Qi7rew3T6
key: uri-bytestring-0.2.3.3-5AAepp46BcPG5Qi7rew3T6
license: BSD3
copyright: Soostone Inc.
maintainer: Michael Xavier <michael.xavier@soostone.com>
homepage: https://github.com/Soostone/uri-bytestring
synopsis: Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.
category: Web
author: Doug Beardsley, Michael Xavier
exposed: True
exposed-modules:
    URI.ByteString URI.ByteString.QQ
hidden-modules: URI.ByteString.Lens URI.ByteString.Types
                URI.ByteString.Internal
abi: 078c6c79ad1b788ca3a32f989335bce9
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/uri-bytestring-0.2.3.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/uri-bytestring-0.2.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/uri-bytestring-0.2.3.3
hs-libraries: HSuri-bytestring-0.2.3.3-5AAepp46BcPG5Qi7rew3T6
depends:
    attoparsec-0.13.1.0-7xLJO1EwFQpJLBzOR8WqkC base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    containers-0.5.7.1 template-haskell-2.11.1.0
    th-lift-instances-0.1.11-IT2AhfETPO082BwRxXIbOF
haddock-interfaces: /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock
haddock-html: /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-0.2.3.3-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-bytestring
version: 0.2.3.3
id: uri-bytestring-0.2.3.3-4LlySgI3f0pFHuLHqRIQcC
key: uri-bytestring-0.2.3.3-4LlySgI3f0pFHuLHqRIQcC
license: BSD3
copyright: Soostone Inc.
maintainer: Michael Xavier <michael.xavier@soostone.com>
homepage: https://github.com/Soostone/uri-bytestring
synopsis: Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.
category: Web
author: Doug Beardsley, Michael Xavier
exposed: True
exposed-modules:
    URI.ByteString URI.ByteString.QQ
hidden-modules: URI.ByteString.Lens URI.ByteString.Types
                URI.ByteString.Internal
abi: ecf7b28b35e531f2cada2353277ccce9
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/uri-bytestring-0.2.3.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/uri-bytestring-0.2.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/uri-bytestring-0.2.3.3
hs-libraries: HSuri-bytestring-0.2.3.3-4LlySgI3f0pFHuLHqRIQcC
depends:
    attoparsec-0.13.2.0-JkqjYPxw7sG9Iq2J4E1Ndn base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    containers-0.5.7.1 template-haskell-2.11.1.0
    th-lift-instances-0.1.11-IT2AhfETPO082BwRxXIbOF
haddock-interfaces: /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock
haddock-html: /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
